@@ -6,7 +6,7 @@ from django.db.models import Q
 from django.db.models.manager import Manager
 from django import forms
 from django.utils.http import int_to_base36
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext, ugettext_lazy as _
 
 from mezzanine.accounts import get_profile_model, get_profile_user_fieldname
 from mezzanine.conf import settings
@@ -53,9 +53,9 @@ class LoginForm(Html5Mixin, forms.Form):
         self._user = authenticate(username=username, password=password)
         if self._user is None:
             raise forms.ValidationError(
-                             _("Invalid username/email and password"))
+                             ugettext("Invalid username/email and password"))
         elif not self._user.is_active:
-            raise forms.ValidationError(_("Your account is inactive"))
+            raise forms.ValidationError(ugettext("Your account is inactive"))
         return self.cleaned_data
 
     def save(self):
@@ -87,7 +87,7 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
         self._signup = self.instance.id is None
         user_fields = User._meta.get_all_field_names()
         try:
-            self.fields["username"].help_text = _(
+            self.fields["username"].help_text = ugettext(
                         "Only letters, numbers, dashes or underscores please")
         except KeyError:
             pass
@@ -103,7 +103,7 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
                 if not self._signup:
                     self.fields[field].required = False
                     if field == "password1":
-                        self.fields[field].help_text = _(
+                        self.fields[field].help_text = ugettext(
                         "Leave blank unless you want to change your password")
         # Add any profile fields to the form.
         self._has_profile = Profile is not None
@@ -126,14 +126,16 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
         """
         username = self.cleaned_data.get("username")
         if username.lower() != slugify(username).lower():
-            raise forms.ValidationError(_("Username can only contain letters, "
-                                          "numbers, dashes or underscores."))
+            raise forms.ValidationError(
+                ugettext("Username can only contain letters, numbers, dashes "
+                         "or underscores."))
         lookup = {"username__iexact": username}
         try:
             User.objects.exclude(id=self.instance.id).get(**lookup)
         except User.DoesNotExist:
             return username
-        raise forms.ValidationError(_("This username is already registered"))
+        raise forms.ValidationError(
+                            ugettext("This username is already registered"))
 
     def clean_password2(self):
         """
@@ -146,10 +148,11 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
         if password1:
             errors = []
             if password1 != password2:
-                errors.append(_("Passwords do not match"))
+                errors.append(ugettext("Passwords do not match"))
             if len(password1) < settings.ACCOUNTS_MIN_PASSWORD_LENGTH:
-                errors.append(_("Password must be at least %s characters") %
-                              settings.ACCOUNTS_MIN_PASSWORD_LENGTH)
+                errors.append(
+                        ugettext("Password must be at least %s characters") %
+                        settings.ACCOUNTS_MIN_PASSWORD_LENGTH)
             if errors:
                 self._errors["password1"] = self.error_class(errors)
         return password2
@@ -162,7 +165,8 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
         qs = User.objects.exclude(id=self.instance.id).filter(email=email)
         if len(qs) == 0:
             return email
-        raise forms.ValidationError(_("This email is already registered"))
+        raise forms.ValidationError(
+                                ugettext("This email is already registered"))
 
     def save(self, *args, **kwargs):
         """
@@ -237,7 +241,7 @@ class PasswordResetForm(Html5Mixin, forms.Form):
             user = User.objects.get(username_or_email, is_active=True)
         except User.DoesNotExist:
             raise forms.ValidationError(
-                             _("Invalid username/email"))
+                             ugettext("Invalid username/email"))
         else:
             self._user = user
         return self.cleaned_data
