@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 from django.contrib.auth.tokens import default_token_generator
 from django.core import mail
 from django.core.urlresolvers import reverse
+from django.forms.fields import DateField, DateTimeField
 from django.utils.http import int_to_base36
 
 from mezzanine.accounts import get_profile_model, get_profile_user_fieldname
@@ -32,14 +33,17 @@ class AccountsTests(TestCase):
         # Profile fields
         Profile = get_profile_model()
         if Profile is not None:
+            from mezzanine.accounts.forms import ProfileFieldsForm
             user_fieldname = get_profile_user_fieldname()
-            for field in Profile._meta.fields:
-                if field.name not in (user_fieldname, "id"):
-                    if field.choices:
-                        value = field.choices[0][0]
+            for name, field in ProfileFieldsForm().fields.items():
+                if name not in (user_fieldname, "id"):
+                    if hasattr(field, "choices"):
+                        value = list(field.choices)[0][0]
+                    elif isinstance(field, (DateField, DateTimeField)):
+                        value = "9001-04-20"
                     else:
                         value = test_value
-                    data[field.name] = value
+                    data[name] = value
         return data
 
     def test_account(self):
@@ -47,7 +51,6 @@ class AccountsTests(TestCase):
         Test account creation.
         """
         # Verification not required - test an active user is created.
-
         data = self.account_data("test1")
         settings.ACCOUNTS_VERIFICATION_REQUIRED = False
         response = self.client.post(reverse("signup"), data, follow=True)
