@@ -1,17 +1,20 @@
+from __future__ import print_function
+from __future__ import unicode_literals
+from future.builtins import int
 
 from datetime import datetime
+from json import loads
 from optparse import make_option
 from time import sleep
-from urllib import urlopen
+
+try:
+    from urllib.request import urlopen
+except ImportError:
+    from urllib import urlopen
 
 from django.core.management.base import CommandError
 from django.utils.html import strip_tags
 
-try:
-    from json import loads
-except ImportError:  # Python < 2.6
-    from django.utils.simplejson import loads
-
 from mezzanine.blog.management.base import BaseImporterCommand
 
 
@@ -58,7 +61,7 @@ class Command(BaseImporterCommand):
             try:
                 call_url = "%s?start=%s" % (json_url, start_index)
                 if verbosity >= 2:
-                    print "Calling %s" % call_url
+                    print("Calling %s" % call_url)
                 response = urlopen(call_url)
                 if response.code == 404:
                     raise CommandError("Invalid Tumblr user.")
@@ -73,7 +76,7 @@ class Command(BaseImporterCommand):
                     continue
                 elif response.code != 200:
                     raise IOError("HTTP status %s" % response.code)
-            except IOError, e:
+            except IOError as e:
                 error = "Error communicating with Tumblr API (%s)" % e
                 raise CommandError(error)
 
