@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 
 from django.contrib.auth import REDIRECT_FIELD_NAME
-from django.core.exceptions import MiddlewareNotUsed
+from django.core.exceptions import ImproperlyConfigured, MiddlewareNotUsed
 from django.http import HttpResponse, Http404
 from django.shortcuts import redirect
 from django.utils.http import urlquote
@@ -63,16 +63,25 @@ class PageMiddleware(object):
             return installed
 
     def process_view(self, request, view_func, view_args, view_kwargs):
+        """
+        Per-request mechanics for the current page object.
+        """
 
+        cp = "mezzanine.pages.context_processors.page"
+        if cp not in settings.TEMPLATE_CONTEXT_PROCESSORS:
+            raise ImproperlyConfigured("%s is missing from "
+                "settings.TEMPLATE_CONTEXT_PROCESSORS" % cp)
+
+        # Load the closest matching page by slug, and assign it to the
+        # request object. If none found, skip all further processing.
         slug = path_to_slug(request.path_info)
         pages = Page.objects.with_ascendants_for_slug(slug,
                         for_user=request.user, include_login_required=True)
         if pages:
             page = pages[0]
+            setattr(request, "page", page)
         else:
-            # If we can't find a page matching this slug or any
-            # of its sub-slugs, skip all further processing.
-            return None
+            return
 
         # Handle ``page.login_required``.
         if page.login_required and not request.user.is_authenticated():
@@ -80,15 +89,7 @@ class PageMiddleware(object):
             bits = (settings.LOGIN_URL, REDIRECT_FIELD_NAME, path)
             return redirect("%s?%s=%s" % bits)
 
-        if page.slug == slug and view_func == page_view:
-            # Add the page to the ``extra_context`` arg for the
-            # page view, which is responsible for choosing which
-            # template to use, and raising 404 if there's no page
-            # instance loaded.
-            view_kwargs.setdefault("extra_context", {})
-            view_kwargs["extra_context"]["page"] = page
-
-        # We also first do wacky check with non-page views and 404s.
+        # Here we do a wacky check with non-page views and 404s.
         # Basically if the view function isn't the page view and
         # raises a 404, but also matches an exact page slug, we then
         # forget about the non-page view, and run the page view
@@ -96,7 +97,7 @@ class PageMiddleware(object):
         # This check allows us to set up pages with URLs that also
         # match non-page urlpatterns, for example a page could be
         # created with the URL /blog/about/, which would match the
-        # blog urlpattern, and asusming there wasn't a blog post
+        # blog urlpattern, and assuming there wasn't a blog post
         # with the slug "about", would raise a 404.
         try:
             response = view_func(request, *view_args, **view_kwargs)
@@ -106,29 +107,10 @@ class PageMiddleware(object):
                 # Matched a non-page urlpattern, but got a 404
                 # for a URL that matches a valid page slug, so
                 # use the page view.
-                view_kwargs = {
-                    "extra_context": {"page": page}
-                }
-                view_func = page_view
-                response = view_func(request, slug, **view_kwargs)
+                response = page_view(request, slug, **view_kwargs)
             else:
                 raise
 
-        # If we can't add context to the response we just return it.
-        # (redirects, etc)
-        if getattr(response, "context_data", None) is None:
-            return response
-
-        # Add the page to its template context, and set helper
-        # attributes like ``is_current``.
-        response.context_data["page"] = page
-        try:
-            response.context_data["editable_obj"]
-        except KeyError:
-            response.context_data["editable_obj"] = page
-        response.context_data["_current_page"] = page
-        page.set_helpers(response.context_data)
-
         # Run page processors.
         model_processors = page_processors.processors[page.content_model]
         slug_processors = page_processors.processors["slug:%s" % page.slug]
