@@ -1,5 +1,5 @@
 from __future__ import unicode_literals
-from future.builtins import str
+from future.builtins import str as _str
 
 from collections import defaultdict
 
@@ -28,7 +28,7 @@ def processor_for(content_model_or_slug, exact_page=False):
     """
     content_model = None
     slug = ""
-    if isinstance(content_model_or_slug, str):
+    if isinstance(content_model_or_slug, (str, _str)):
         try:
             content_model = get_model(*content_model_or_slug.split(".", 1))
         except TypeError:
